@@ -7,6 +7,8 @@
 
 #   2016/07/05 - Champ Clark - Replaced jsonc -> libfastjson
 #   2017/06/25 - Added "--enable-redis".
+#   2017/11/07 - Added test for "saganpeek". 
+#   2018/05/08 - Added FLAGS for make
 
 # Champ Clark III 
 
@@ -29,12 +31,16 @@ NOFLAG="--disable-snortsam --disable-syslog --disable-lognorm --disable-libpcap
 
 LOG="output.log" 
 
-#autoreconf -vfi
+MAKE_FLAGS="-j5"
+
+autoreconf -vfi
 
 echo "**** STANDARD BUILD | NO FLAGS ****"
 echo "**** STANDARD BUILD | NO FLAGS ****" >> $LOG
 
-make clean
+#make clean
+#cd tools && make clean && cd ..
+
 CFLAGS=-Wall ./configure
 
 if [ "$?" != "0" ]
@@ -43,7 +49,8 @@ if [ "$?" != "0" ]
 	exit
         fi
 
-make 2>> $LOG
+make $MAKE_FLAGS 2>> $LOG
+cd tools && make $MAKE_FLAGS && cd .. 2>> $LOG
 
 if [ "$?" != "0" ] 
 	then
@@ -55,6 +62,8 @@ echo "**** ALL FLAGS ****"
 echo "**** ALL FLAGS ****" >> $LOG
 
 make clean
+cd tools && make clean && cd .. 
+
 CFLAGS=-Wall ./configure $ALLFLAGS
 
 if [ "$?" != "0" ]
@@ -63,7 +72,8 @@ if [ "$?" != "0" ]
         exit
         fi
 
-make 2>> $LOG
+make $MAKE_FLAGS 2>> $LOG
+cd tools && make $MAKE_FLAGS && cd .. 2>> $LOG
 
 if [ "$?" != "0" ] 
         then
@@ -75,6 +85,8 @@ echo "****  NO FLAGS ****"
 echo "****  NO FLAGS ****" >> $LOG
 
 make clean
+cd tools && make clean && cd ..
+
 CFLAGS=-Wall ./configure $NOFLAG
 
 if [ "$?" != "0" ]
@@ -83,7 +95,8 @@ if [ "$?" != "0" ]
         exit
         fi
 
-make 2>> $LOG
+make $MAKE_FLAGS 2>> $LOG
+cd tools && make $MAKE_FLAGS && cd .. 2>> $LOG
 
 if [ "$?" != "0" ] 
         then
@@ -95,6 +108,7 @@ for I in $STANDARD
 do
 
 make clean
+cd tools && make clean && cd ..
 
 echo "**** FLAGS $I *****"
 echo "**** FLAGS $I *****" >> $LOG
@@ -107,7 +121,8 @@ if [ "$?" != "0" ]
         exit
         fi
 
-make 2>> $LOG
+make $MAKE_FLAGS 2>> $LOG
+cd tools && make $MAKE_FLAGS && cd .. 2>> $LOG
 
 if [ "$?" != "0" ] 
         then
@@ -120,6 +135,7 @@ for I in $ALLFLAGS
 do
 
 make clean
+cd tools && make clean && cd .. 
 
 echo "**** FLAGS $I *****"
 echo "**** FLAGS $I *****" >> $LOG
@@ -132,7 +148,8 @@ if [ "$?" != "0" ]
         exit
         fi
 
-make 2>> $LOG
+make $MAKE_FLAGS 2>> $LOG
+cd tools && make $MAKE_FLAGS && cd .. 2>> $LOG
 
 if [ "$?" != "0" ]
         then
@@ -145,6 +162,7 @@ for I in $NOFLAGS
 do
 
 make clean
+cd tools && make clean && cd ..
 
 echo "**** FLAGS $I *****"
 echo "**** FLAGS $I *****" >> $LOG
@@ -157,7 +175,8 @@ if [ "$?" != "0" ]
         exit
         fi
 
-make 2>> $LOG
+make $MAKE_FLAGS 2>> $LOG
+cd tools && make $MAKE_FLAGS && cd .. 2>> $LOG
 
 if [ "$?" != "0" ]
         then
