@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -18,9 +18,9 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-sbool After_By_Src ( int rule_position, char *ip_src, uint32_t ip_src_u32 );
-sbool After_By_Dst ( int rule_position, char *ip_dst, uint32_t ip_dst_u32 );
-sbool After_By_Username( int rule_position, char *normalize_username );
-sbool After_By_SrcPort( int rule_position, uint32_t ip_srcport_u32 );
-sbool After_By_DstPort( int rule_position, uint32_t ip_dstport_u32 );
+sbool After_By_Src ( int rule_position, char *ip_src, unsigned char *ip_src_bits, char *select, char *syslog_message );
+sbool After_By_Dst ( int rule_position, char *ip_dst, unsigned char *ip_dst_bits, char *select, char *syslog_message );
+sbool After_By_Username( int rule_position, char *normalize_username, char *select, char *syslog_message );
+sbool After_By_SrcPort( int rule_position, uint32_t ip_srcport_u32, char *select );
+sbool After_By_DstPort( int rule_position, uint32_t ip_dstport_u32, char *select );
 
