@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -25,8 +25,8 @@
 
 /* Classification strucure */
 typedef struct _Class_Struct _Class_Struct;
-struct _Class_Struct {
-    unsigned s_size_class;
+struct _Class_Struct
+{
     char s_shortname[512];
     char s_desc[512];
     int  s_priority;
