@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -29,7 +29,7 @@
 
 #ifdef HAVE_LIBMAXMINDDB
 void Open_GeoIP2_Database( void );
-int GeoIP2_Lookup_Country( char *, int );
+int GeoIP2_Lookup_Country( char *, unsigned char *ip_bits, int );
 #endif
 
 
