@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -24,7 +24,8 @@
 
 #include "parsers/strstr-asm/strstr-hook.h"
 
-void  Parse_IP( char *, int, char *str, size_t size );
+int Parse_IP( char *syslog_message, struct _Sagan_Lookup_Cache_Entry *lookup_cache );
+
 int   Parse_Src_Port( char * );
 int   Parse_Dst_Port( char * );
 int   Parse_Proto( char * );
@@ -32,5 +33,6 @@ int   Parse_Proto_Program( char * );
 void  Parse_Hash( char *, int, char *str, size_t size );
 void  Parse_Hash_Cleanup(char *, char *str, size_t size );
 
+/* IP Lookup cache */
 
 
