@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -25,7 +25,8 @@
 /* Storage for protocol.map (program search) */
 
 typedef struct _Sagan_Protocol_Map_Program _Sagan_Protocol_Map_Program;
-struct _Sagan_Protocol_Map_Program {
+struct _Sagan_Protocol_Map_Program
+{
     int type;
     int proto;
     int nocase;
@@ -35,7 +36,8 @@ struct _Sagan_Protocol_Map_Program {
 /* Storage for protocol.map (message search) */
 
 typedef struct _Sagan_Protocol_Map_Message _Sagan_Protocol_Map_Message;
-struct _Sagan_Protocol_Map_Message {
+struct _Sagan_Protocol_Map_Message
+{
     int type;
     int proto;
     int nocase;
