@@ -1,7 +1,7 @@
 /* $Id$ */
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -31,6 +31,7 @@
 
 #include <stdio.h>
 #include <stdint.h>
+#include <stddef.h>
 #include <pcre.h>
 #include <time.h>
 #include <arpa/inet.h>
@@ -41,7 +42,6 @@
 #include <maxminddb.h>
 #endif
 
-
 #ifndef HAVE_STRLCAT
 size_t strlcat(char *, const char *, size_t );
 #endif
@@ -60,7 +60,7 @@ size_t strlcpy(char *, const char *, size_t );
 #define SetThreadName(n) ({ \
     char tname[16] = ""; \
     if (strlen(n) > 16) \
-        Sagan_Log(S_WARN, "Thread name is too long, truncating it..."); \
+        Sagan_Log(WARN, "Thread name is too long, truncating it..."); \
     strlcpy(tname, n, 16); \
     pthread_set_name_np(pthread_self(), tname); \
     0; \
@@ -81,11 +81,11 @@ size_t strlcpy(char *, const char *, size_t );
 #define SetThreadName(n) ({ \
     char tname[THREAD_NAME_LEN + 1] = ""; \
     if (strlen(n) > THREAD_NAME_LEN) \
-        Sagan_Log(S_WARN, "Thread name is too long, truncating it..."); \
+        Sagan_Log(WARN, "Thread name is too long, truncating it..."); \
     strlcpy(tname, n, THREAD_NAME_LEN); \
     int ret = 0; \
     if ((ret = prctl(PR_SET_NAME, tname, 0, 0, 0)) < 0) \
-        Sagan_Log(S_WARN, "Error setting thread name \"%s\": %s", tname, strerror(errno)); \
+        Sagan_Log(WARN, "Error setting thread name \"%s\": %s", tname, strerror(errno)); \
     ret; \
 })
 #else
@@ -100,37 +100,44 @@ typedef char sbool;	/* From rsyslog. 'bool' causes compatiablity problems on OSX
 sbool     Is_Numeric (char *);
 void      To_UpperC(char* const );
 void      To_LowerC(char* const );
-int	  Check_Endian( void );
+sbool	  Check_Endian( void );
 void      Usage( void );
 void      Chroot( const char * );
 void	  Remove_Return(char *);
 int       Classtype_Lookup( const char *, char *, size_t size );
 void      Remove_Spaces(char *);
 void      Between_Quotes( char *, char *str, size_t size );
-double    CalcPct(uintmax_t, uintmax_t);
+double    CalcPct(uint64_t, uint64_t);
 void      Replace_String(char *, char *, char *, char *str, size_t size);
-uintmax_t Value_To_Seconds (char *, uintmax_t);
+uint64_t Value_To_Seconds (char *, uint64_t);
 void      Sagan_Log( int, const char *, ... );
 void      Droppriv( void );
 int       DNS_Lookup( char *, char *str, size_t size );
 void      Var_To_Value(char *, char *str, size_t size);
-uint32_t  IP2Bit (char * );
-void      Bit2IP(uint32_t, char *str, size_t size);
+sbool     IP2Bit (char *, unsigned char * );
+sbool     Mask2Bit (int, unsigned char * );
+const char *Bit2IP(unsigned char *, char *str, size_t size);
 sbool     Validate_HEX (const char *);
 void      Content_Pipe(char *, int, const char *, char *, size_t size);
-sbool     is_rfc1918 ( uint32_t );
+sbool     is_notroutable ( unsigned char * );
+sbool     is_inrange ( unsigned char *, unsigned char *, int );
 void      Replace_Sagan( char *, char *, char *str, size_t size);
 int       Character_Count ( char *, char *);
 sbool     Wildcard( char *, char *);
 void      Open_Log_File( sbool, int );
 int       Check_Var(const char *);
-void      Netaddr_To_Range( char *, char *str, size_t size );
-void      Strip_Chars(const char *string, const char *chars, char *str, size_t size);
+int       Netaddr_To_Range( char *, unsigned char * );
+void      Strip_Chars(const char *string, const char *chars, char *str);
 sbool     Is_IP (char *str);
+sbool     Is_IPv6 (char *str);
 sbool     File_Lock ( int );
 sbool     File_Unlock ( int );
 sbool     Check_Content_Not( char * );
 uint32_t  Djb2_Hash( char * );
+sbool     Starts_With(const char *str, const char *prefix);
+char      *strrpbrk(const char *str, const char *accept);
+
+
 
 #if defined(F_GETPIPE_SZ) && defined(F_SETPIPE_SZ)
 void      Set_Pipe_Size( FILE * );
@@ -140,7 +147,9 @@ void      Set_Pipe_Size( FILE * );
 #ifdef __OpenBSD__
 /* OpenBSD won't allow for this test:
  * "suricata(...): mprotect W^X violation" */
+#ifndef PageSupportsRWX()
 #define PageSupportsRWX() 0
+#endif
 #else
 #ifndef HAVE_SYS_MMAN_H
 #define PageSupportsRWX() 1
@@ -151,14 +160,16 @@ int       PageSupportsRWX(void);
 
 
 typedef struct _SaganDNSCache _SaganDNSCache;
-struct _SaganDNSCache {
+struct _SaganDNSCache
+{
 
     char hostname[64];
     char src_ip[20];
 };
 
 typedef struct _Sagan_IPC_Counters _Sagan_IPC_Counters;
-struct _Sagan_IPC_Counters {
+struct _Sagan_IPC_Counters
+{
 
     int  xbit_count;
     int	 thresh_count_by_src;
@@ -179,37 +190,38 @@ struct _Sagan_IPC_Counters {
 };
 
 typedef struct _SaganCounters _SaganCounters;
-struct _SaganCounters {
+struct _SaganCounters
+{
 
-    uintmax_t threshold_total;
-    uintmax_t after_total;
-    uintmax_t sagantotal;
-    uintmax_t saganfound;
-    uintmax_t sagan_output_drop;
-    uintmax_t sagan_processor_drop;
-    uintmax_t sagan_log_drop;
-    uintmax_t dns_cache_count;
-    uintmax_t dns_miss_count;
-    uintmax_t fwsam_count;
-    uintmax_t ignore_count;
-    uintmax_t blacklist_count;
+    uint64_t threshold_total;
+    uint64_t after_total;
+    uint64_t sagantotal;
+    uint64_t saganfound;
+    uint64_t sagan_output_drop;
+    uint64_t sagan_processor_drop;
+    uint64_t sagan_log_drop;
+    uint64_t dns_cache_count;
+    uint64_t dns_miss_count;
+    uint64_t fwsam_count;
+    uint64_t ignore_count;
+    uint64_t blacklist_count;
 
-    uintmax_t alert_total;
+    uint64_t alert_total;
 
-    uintmax_t malformed_host;
-    uintmax_t malformed_facility;
-    uintmax_t malformed_priority;
-    uintmax_t malformed_level;
-    uintmax_t malformed_tag;
-    uintmax_t malformed_date;
-    uintmax_t malformed_time;
-    uintmax_t malformed_program;
-    uintmax_t malformed_message;
+    uint64_t malformed_host;
+    uint64_t malformed_facility;
+    uint64_t malformed_priority;
+    uint64_t malformed_level;
+    uint64_t malformed_tag;
+    uint64_t malformed_date;
+    uint64_t malformed_time;
+    uint64_t malformed_program;
+    uint64_t malformed_message;
 
-    uintmax_t worker_thread_exhaustion;
+    uint64_t worker_thread_exhaustion;
 
-    uintmax_t blacklist_hit_count;
-    uintmax_t blacklist_lookup_count;
+    uint64_t blacklist_hit_count;
+    uint64_t blacklist_lookup_count;
 
     int	     thread_output_counter;
     int	     thread_processor_counter;
@@ -245,41 +257,41 @@ struct _SaganCounters {
 
     int	      rules_loaded_count;
 
-    uintmax_t follow_flow_total;			/* This will only be needed if follow_flow is an option */
-    uintmax_t follow_flow_drop;	     		        /* Amount of flows that did not match and were dropped */
+    uint64_t follow_flow_total;			/* This will only be needed if follow_flow is an option */
+    uint64_t follow_flow_drop;	     		        /* Amount of flows that did not match and were dropped */
 
 #ifdef HAVE_LIBMAXMINDDB
-    uintmax_t geoip2_hit;				/* GeoIP2 hit count */
-    uintmax_t geoip2_lookup;				/* Total lookups */
-    uintmax_t geoip2_miss;				/* Misses (country not found) */
+    uint64_t geoip2_hit;				/* GeoIP2 hit count */
+    uint64_t geoip2_lookup;				/* Total lookups */
+    uint64_t geoip2_miss;				/* Misses (country not found) */
 #endif
 
 #ifdef WITH_BLUEDOT
-    uintmax_t bluedot_ip_cache_count;                      /* Bluedot cache processor */
-    uintmax_t bluedot_ip_cache_hit;                        /* Bluedot hit's from Cache */
-    uintmax_t bluedot_ip_positive_hit;
-    uintmax_t bluedot_ip_total;
+    uint64_t bluedot_ip_cache_count;                      /* Bluedot cache processor */
+    uint64_t bluedot_ip_cache_hit;                        /* Bluedot hit's from Cache */
+    uint64_t bluedot_ip_positive_hit;
+    uint64_t bluedot_ip_total;
 
-    uintmax_t bluedot_mdate;					   /* Hits , but where over a modification date */
-    uintmax_t bluedot_cdate;            	                   /* Hits , but where over a creation date */
-    uintmax_t bluedot_mdate_cache;                                 /* Hits from cache , but where over a modification date */
-    uintmax_t bluedot_cdate_cache;      			   /* Hits from cache , but where over a create date */
-    uintmax_t bluedot_error_count;
+    uint64_t bluedot_mdate;					   /* Hits , but where over a modification date */
+    uint64_t bluedot_cdate;            	                   /* Hits , but where over a creation date */
+    uint64_t bluedot_mdate_cache;                                 /* Hits from cache , but where over a modification date */
+    uint64_t bluedot_cdate_cache;      			   /* Hits from cache , but where over a create date */
+    uint64_t bluedot_error_count;
 
-    uintmax_t bluedot_hash_cache_count;
-    uintmax_t bluedot_hash_cache_hit;
-    uintmax_t bluedot_hash_positive_hit;
-    uintmax_t bluedot_hash_total;
+    uint64_t bluedot_hash_cache_count;
+    uint64_t bluedot_hash_cache_hit;
+    uint64_t bluedot_hash_positive_hit;
+    uint64_t bluedot_hash_total;
 
-    uintmax_t bluedot_url_cache_count;
-    uintmax_t bluedot_url_cache_hit;
-    uintmax_t bluedot_url_positive_hit;
-    uintmax_t bluedot_url_total;
+    uint64_t bluedot_url_cache_count;
+    uint64_t bluedot_url_cache_hit;
+    uint64_t bluedot_url_positive_hit;
+    uint64_t bluedot_url_total;
 
-    uintmax_t bluedot_filename_cache_count;
-    uintmax_t bluedot_filename_cache_hit;
-    uintmax_t bluedot_filename_positive_hit;
-    uintmax_t bluedot_filename_total;
+    uint64_t bluedot_filename_cache_count;
+    uint64_t bluedot_filename_cache_hit;
+    uint64_t bluedot_filename_positive_hit;
+    uint64_t bluedot_filename_total;
 
     int bluedot_cat_count;
 
@@ -287,18 +299,19 @@ struct _SaganCounters {
 
 
 #ifdef HAVE_LIBESMTP
-    uintmax_t esmtp_count_success;
-    uintmax_t esmtp_count_failed;
+    uint64_t esmtp_count_success;
+    uint64_t esmtp_count_failed;
 #endif
 
 #ifdef HAVE_LIBHIREDIS
-    uintmax_t redis_writer_threads_drop;
+    uint64_t redis_writer_threads_drop;
 #endif
 
 };
 
 typedef struct _SaganDebug _SaganDebug;
-struct _SaganDebug {
+struct _SaganDebug
+{
 
     sbool debugsyslog;
     sbool debugload;
@@ -312,6 +325,7 @@ struct _SaganDebug {
     sbool debuglimits;
     sbool debugipc;
     sbool debugjson;
+    sbool debugparse_ip;
 
 #ifdef HAVE_LIBMAXMINDDB
     sbool debuggeoip2;
@@ -342,14 +356,16 @@ struct _SaganDebug {
 #ifdef HAVE_LIBHIREDIS
 
 typedef struct _Sagan_Redis _Sagan_Redis;
-struct _Sagan_Redis {
+struct _Sagan_Redis
+{
     char redis_command[2048];
 };
 
 #endif
 
 typedef struct _Sagan_Proc_Syslog _Sagan_Proc_Syslog;
-struct _Sagan_Proc_Syslog {
+struct _Sagan_Proc_Syslog
+{
     char syslog_host[50];
     char syslog_facility[50];
     char syslog_priority[50];
@@ -363,13 +379,16 @@ struct _Sagan_Proc_Syslog {
 };
 
 typedef struct _Sagan_Event _Sagan_Event;
-struct _Sagan_Event {
+struct _Sagan_Event
+{
 
     char *ip_src;
     char *ip_dst;
     int   dst_port;
     int   src_port;
 
+    char *selector;
+
     struct timeval event_time;
 
     int  found;
@@ -406,141 +425,171 @@ struct _Sagan_Event {
     unsigned long generatorid;
     unsigned long alertid;
 
-
+    json_object *json_normalize;
 };
 
 
 /* Thresholding structure by source */
 
 typedef struct thresh_by_src_ipc thresh_by_src_ipc;
-struct thresh_by_src_ipc {
-    uint32_t ipsrc;
+struct thresh_by_src_ipc
+{
+    unsigned char ipsrc[MAXIPBIT];
     int  count;
-    uintmax_t utime;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
+    char syslog_message[MAX_SYSLOGMSG];
+    char signature_msg[MAX_SAGAN_MSG];
 };
 
 
 /* Thresholding structure by destination */
 
 typedef struct thresh_by_dst_ipc thresh_by_dst_ipc;
-struct thresh_by_dst_ipc {
-    uint32_t ipdst;
+struct thresh_by_dst_ipc
+{
+    unsigned char ipdst[MAXIPBIT];
     int  count;
-    uintmax_t utime;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
+    char syslog_message[MAX_SYSLOGMSG];
+    char signature_msg[MAX_SAGAN_MSG];
 };
 
 
 /* Thresholding structure by source port */
 
 typedef struct thresh_by_srcport_ipc thresh_by_srcport_ipc;
-struct thresh_by_srcport_ipc {
+struct thresh_by_srcport_ipc
+{
     uint32_t ipsrcport;
     int  count;
-    uintmax_t utime;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
 };
 
 /* Thresholding structure by destination port */
 
 typedef struct thresh_by_dstport_ipc thresh_by_dstport_ipc;
-struct thresh_by_dstport_ipc {
+struct thresh_by_dstport_ipc
+{
     uint32_t ipdstport;
     int  count;
-    uintmax_t utime;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
 };
 
 
 /* Thesholding structure by username */
 
 typedef struct thresh_by_username_ipc thresh_by_username_ipc;
-struct thresh_by_username_ipc {
+struct thresh_by_username_ipc
+{
     char username[128];
     int  count;
-    uintmax_t utime;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
+    char syslog_message[MAX_SYSLOGMSG];
+    char signature_msg[MAX_SAGAN_MSG];
 };
 
 /* After structure by source */
 
 typedef struct after_by_src_ipc after_by_src_ipc;
-struct after_by_src_ipc {
-    uint32_t ipsrc;
-    uintmax_t count;
-    uintmax_t total_count;
-    uintmax_t utime;
+struct after_by_src_ipc
+{
+    unsigned char ipsrc[MAXIPBIT];
+    uint64_t count;
+    uint64_t total_count;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
+    char syslog_message[MAX_SYSLOGMSG];
+    char signature_msg[MAX_SAGAN_MSG];
 };
 
 /* After structure by destination */
 
 typedef struct after_by_dst_ipc after_by_dst_ipc;
-struct after_by_dst_ipc {
-    uint32_t ipdst;
+struct after_by_dst_ipc
+{
+    unsigned char ipdst[MAXIPBIT];
     int  count;
-    uintmax_t total_count;
-    uintmax_t utime;
+    uint64_t total_count;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
+    char syslog_message[MAX_SYSLOGMSG];
+    char signature_msg[MAX_SAGAN_MSG];
+
 };
 
 /* After structure by source port */
 
 typedef struct after_by_srcport_ipc after_by_srcport_ipc;
-struct after_by_srcport_ipc {
+struct after_by_srcport_ipc
+{
     uint32_t ipsrcport;
-    uintmax_t count;
-    uintmax_t total_count;
-    uintmax_t utime;
+    uint64_t count;
+    uint64_t total_count;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
 };
 
 /* After structure by destination port */
 
 typedef struct after_by_dstport_ipc after_by_dstport_ipc;
-struct after_by_dstport_ipc {
+struct after_by_dstport_ipc
+{
     uint32_t ipdstport;
-    uintmax_t count;
-    uintmax_t total_count;
-    uintmax_t utime;
+    uint64_t count;
+    uint64_t total_count;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
 };
 
 /* After structure by username */
 
 typedef struct after_by_username_ipc after_by_username_ipc;
-struct after_by_username_ipc {
+struct after_by_username_ipc
+{
     char username[128];
-    uintmax_t count;
-    uintmax_t total_count;
-    uintmax_t utime;
+    uint64_t count;
+    uint64_t total_count;
+    uint64_t utime;
     char sid[20];
     int expire;
+    char selector[MAXSELECTOR];
+    char syslog_message[MAX_SYSLOGMSG];
+    char signature_msg[MAX_SAGAN_MSG];
 };
 
 typedef struct _SaganVar _SaganVar;
-struct _SaganVar {
+struct _SaganVar
+{
     char var_name[MAX_VAR_NAME_SIZE];
     char var_value[MAX_VAR_VALUE_SIZE];
 };
 
-typedef struct network_addr {
-    in_addr_t addr;
-    int pfx;
-} network_addr_t;
-
 typedef struct _Sagan_Processor_Info _Sagan_Processor_Info;
-struct _Sagan_Processor_Info {
+struct _Sagan_Processor_Info
+{
 
     char *processor_name;
     char *processor_facility;
@@ -552,8 +601,26 @@ struct _Sagan_Processor_Info {
     int   processor_generator_id;
 };
 
+/* IP Lookup cache */
+
+typedef struct _Sagan_Lookup_Cache_Entry _Sagan_Lookup_Cache_Entry;
+struct _Sagan_Lookup_Cache_Entry
+{
+    char ip[MAXIP];
+    unsigned char ip_bits[MAXIPBIT];
+    int  port;
+    unsigned char proto;
+    sbool status;
+};
+
+typedef struct _Sagan_Lookup_Cache_Entry _Sagan_Lookup_Cache_Other;
+struct _Sagan_Lookup_Cache_Other
+{
+    int proto;
+};
 
 /* Function that require the above arrays */
 
 int64_t   FlowGetId( _Sagan_Event *);
+void 	  Escape_Chars( char *str_in, char *str, size_t size);
 
