@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -22,5 +22,7 @@
 #include "config.h"             /* From autoconf */
 #endif
 
-void Send_Alert ( _Sagan_Proc_Syslog *, _Sagan_Processor_Info *, char *, char *, char *, char *, int, int, int, int, int, struct timeval tp );
+#include "sagan-defs.h"
+
+void Send_Alert ( _Sagan_Proc_Syslog *, json_object *, _Sagan_Processor_Info *, char *, char *, char *, char *, int, int, int, int, int, struct timeval tp );
 
