@@ -1,6 +1,6 @@
 /*
-** Copyright (C) 2009-2017 Quadrant Information Security <quadrantsec.com>
-** Copyright (C) 2009-2017 Champ Clark III <cclark@quadrantsec.com>
+** Copyright (C) 2009-2018 Quadrant Information Security <quadrantsec.com>
+** Copyright (C) 2009-2018 Champ Clark III <cclark@quadrantsec.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -19,8 +19,8 @@
 */
 
 int  Xbit_Type ( char *, int, const char *);
-sbool Xbit_Condition ( int, char *, char *, int, int );
-sbool Xbit_Count ( int, char *, char * );
-void Xbit_Set(int, char *, char *, int ,int );
+sbool Xbit_Condition ( int, char *, char *, int, int, char * );
+sbool Xbit_Count ( int, char *, char *, char * );
+void Xbit_Set(int, char *, char *, int ,int, char *, _Sagan_Proc_Syslog * );
 
 
